@@ -1,73 +1,3 @@
-"""
-Creating charts.
----------------
-
-We recommend using Altair/pdvega for generating interactive charts: use the supplied `save`
-function.
-
-Example
--------
-
-altair_pandas::
-  # uses the default pandas plotting API
-  from datapane.files import save
-
-  import numpy as np
-
-  pd.set_option('plotting.backend', 'altair')  # Installing altair_pandas registers this.
-
-  data = pd.DataFrame({'x': np.random.randn(200),
-                       'y': np.random.randn(200)})
-
-  plot = data.plot.scatter('x', 'y')
-  save(plot, "scatter")
-
-pdvega::
-
-  from datapane.files import save
-
-  import numpy as np
-  import pdvega
-
-  data = pd.DataFrame({'x': np.random.randn(200),
-                       'y': np.random.randn(200)})
-
-  plot = data.vgplot.scatter('x', 'y')
-  save(plot, "scatter")
-
-altair::
-
-  from datapane.files import save
-
-  import altair as alt
-  import numpy as np
-
-  data = pd.DataFrame({'x': np.random.randn(20),
-                      'y': np.random.randn(20)})
-  plot = alt.Chart(data).mark_bar().encode(
-      y='y',
-      x='x'
-  )
-
-  save(plot, "bars")
-
-Also for your convenience the `save` function is compatible with matplotlib figures, Bokeh Figures, and pandas dataframes (it saves a table in this instance).
-
-Example
--------
-
-::
-
-  from datapane.files import save
-
-  import matplotlib.pyplot as plt
-
-  fig, ax = plt.subplots()
-  ax.plot([1, 2, 3, 4], [1, 4, 9, 16])
-  save(figure, "line.svg")
-  out_df = in_df
-"""
-
 import abc
 import json
 import os
@@ -77,22 +7,16 @@ from pathlib import Path
 from typing import IO, Any, BinaryIO, Generic, Optional, TextIO, Type, TypeVar
 
 import bleach
-import matplotlib.pyplot as plt
 from altair.utils import SchemaBase
-from bokeh.embed import json_item
-from bokeh.layouts import LayoutDOM as BLayout
-from bokeh.plotting.figure import Figure as BFigure
-from folium import Map
-from matplotlib.figure import Axes, Figure
 from numpy import ndarray
 from pandas import DataFrame
 from pandas.io.formats.style import Styler
-from plotly.graph_objects import Figure as PFigure
 
 from datapane.common import log
 
 from .. import DPError
 from .common import DPTmpFile
+from .files_optional import Axes, BFigure, BLayout, Figure, Map, PFigure
 from .report.blocks import DataBlock, DataTable, File, Plot, Table, Text
 
 T = TypeVar("T")
@@ -179,7 +103,7 @@ class PathWrapper(BaseAsset):
 class BaseTable(BaseAsset):
     mimetype = "application/vnd.datapane.table+html"
     ext = ".tbl.html"
-    TABLE_CELLS_LIMIT: int = 2000
+    TABLE_CELLS_LIMIT: int = 5000
     obj_type: U
     block_type = Table
     # TODO - move to own bleach class/module?
@@ -191,7 +115,7 @@ class BaseTable(BaseAsset):
         n_cells = self._get_cells(x)
         if n_cells > self.TABLE_CELLS_LIMIT:
             raise ValueError(
-                f"Dataframe over limit of {self.TABLE_CELLS_LIMIT} cells for dp.Table, consider using dp.DataTable instead"
+                f"Dataframe over limit of {self.TABLE_CELLS_LIMIT} cells for dp.Table, consider using dp.DataTable instead or aggregating the df first"
             )
 
         # sanitise the generated HTML
@@ -257,6 +181,8 @@ class MatplotBasePlot(PlotAsset):
 
     def _write_figure(self, x: Figure) -> DPTmpFile:
         """Creates an SVG from figure"""
+        import matplotlib.pyplot as plt
+
         fn = DPTmpFile(self.ext)
         x = x or plt.gcf()
         x.savefig(str(fn))
@@ -293,6 +219,8 @@ class BokehBasePlot(PlotAsset):
     ext = ".bokeh.json"
 
     def write_file(self, f: TextIO, app):
+        from bokeh.embed import json_item
+
         json.dump(json_item(app), f)
 
 
